==> knative-model-6.3.1-sources.jar: io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubSourceStatusFluent.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributesBuilder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributesFluent;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributes;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GitHubSourceStatusFluent<A extends GitHubSourceStatusFluent<A>> extends Fluent<A>{
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToCeAttributes(Integer index,CloudEventAttributes item);
  public A setToCeAttributes(Integer index,CloudEventAttributes item);
  public A addToCeAttributes(io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributes... items);
  public A addAllToCeAttributes(Collection<CloudEventAttributes> items);
  public A removeFromCeAttributes(io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributes... items);
  public A removeAllFromCeAttributes(Collection<CloudEventAttributes> items);
  public A removeMatchingFromCeAttributes(Predicate<CloudEventAttributesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildCeAttributes instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CloudEventAttributes> getCeAttributes();
  public List<CloudEventAttributes> buildCeAttributes();
  public CloudEventAttributes buildCeAttribute(Integer index);
  public CloudEventAttributes buildFirstCeAttribute();
  public CloudEventAttributes buildLastCeAttribute();
  public CloudEventAttributes buildMatchingCeAttribute(Predicate<CloudEventAttributesBuilder> predicate);
  public Boolean hasMatchingCeAttribute(Predicate<CloudEventAttributesBuilder> predicate);
  public A withCeAttributes(List<CloudEventAttributes> ceAttributes);
  public A withCeAttributes(io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributes... ceAttributes);
  public Boolean hasCeAttributes();
  public A addNewCeAttribute(String source,String type);
  public GitHubSourceStatusFluent.CeAttributesNested<A> addNewCeAttribute();
  public GitHubSourceStatusFluent.CeAttributesNested<A> addNewCeAttributeLike(CloudEventAttributes item);
  public GitHubSourceStatusFluent.CeAttributesNested<A> setNewCeAttributeLike(Integer index,CloudEventAttributes item);
  public GitHubSourceStatusFluent.CeAttributesNested<A> editCeAttribute(Integer index);
  public GitHubSourceStatusFluent.CeAttributesNested<A> editFirstCeAttribute();
  public GitHubSourceStatusFluent.CeAttributesNested<A> editLastCeAttribute();
  public GitHubSourceStatusFluent.CeAttributesNested<A> editMatchingCeAttribute(Predicate<CloudEventAttributesBuilder> predicate);
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public GitHubSourceStatusFluent.ConditionsNested<A> addNewCondition();
  public GitHubSourceStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public GitHubSourceStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public GitHubSourceStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public GitHubSourceStatusFluent.ConditionsNested<A> editFirstCondition();
  public GitHubSourceStatusFluent.ConditionsNested<A> editLastCondition();
  public GitHubSourceStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public String getSinkUri();
  public A withSinkUri(String sinkUri);
  public Boolean hasSinkUri();
  public String getWebhookIDKey();
  public A withWebhookIDKey(String webhookIDKey);
  public Boolean hasWebhookIDKey();
  public interface CeAttributesNested<N> extends Nested<N>,CloudEventAttributesFluent<GitHubSourceStatusFluent.CeAttributesNested<N>>{
    public N and();
    public N endCeAttribute();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<GitHubSourceStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubSourceStatusFluent.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributesBuilder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributesFluent;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributes;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface GitHubSourceStatusFluent<A extends GitHubSourceStatusFluent<A>> extends Fluent<A>{
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToCeAttributes(int index,CloudEventAttributes item);
  public A setToCeAttributes(int index,CloudEventAttributes item);
  public A addToCeAttributes(io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributes... items);
  public A addAllToCeAttributes(Collection<CloudEventAttributes> items);
  public A removeFromCeAttributes(io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributes... items);
  public A removeAllFromCeAttributes(Collection<CloudEventAttributes> items);
  public A removeMatchingFromCeAttributes(Predicate<CloudEventAttributesBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildCeAttributes instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CloudEventAttributes> getCeAttributes();
  public List<CloudEventAttributes> buildCeAttributes();
  public CloudEventAttributes buildCeAttribute(int index);
  public CloudEventAttributes buildFirstCeAttribute();
  public CloudEventAttributes buildLastCeAttribute();
  public CloudEventAttributes buildMatchingCeAttribute(Predicate<CloudEventAttributesBuilder> predicate);
  public Boolean hasMatchingCeAttribute(Predicate<CloudEventAttributesBuilder> predicate);
  public A withCeAttributes(List<CloudEventAttributes> ceAttributes);
  public A withCeAttributes(io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventAttributes... ceAttributes);
  public Boolean hasCeAttributes();
  public A addNewCeAttribute(String source,String type);
  public GitHubSourceStatusFluent.CeAttributesNested<A> addNewCeAttribute();
  public GitHubSourceStatusFluent.CeAttributesNested<A> addNewCeAttributeLike(CloudEventAttributes item);
  public GitHubSourceStatusFluent.CeAttributesNested<A> setNewCeAttributeLike(int index,CloudEventAttributes item);
  public GitHubSourceStatusFluent.CeAttributesNested<A> editCeAttribute(int index);
  public GitHubSourceStatusFluent.CeAttributesNested<A> editFirstCeAttribute();
  public GitHubSourceStatusFluent.CeAttributesNested<A> editLastCeAttribute();
  public GitHubSourceStatusFluent.CeAttributesNested<A> editMatchingCeAttribute(Predicate<CloudEventAttributesBuilder> predicate);
  public A addToConditions(int index,Condition item);
  public A setToConditions(int index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(int index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public GitHubSourceStatusFluent.ConditionsNested<A> addNewCondition();
  public GitHubSourceStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public GitHubSourceStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
  public GitHubSourceStatusFluent.ConditionsNested<A> editCondition(int index);
  public GitHubSourceStatusFluent.ConditionsNested<A> editFirstCondition();
  public GitHubSourceStatusFluent.ConditionsNested<A> editLastCondition();
  public GitHubSourceStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public String getSinkUri();
  public A withSinkUri(String sinkUri);
  public Boolean hasSinkUri();
  public String getWebhookIDKey();
  public A withWebhookIDKey(String webhookIDKey);
  public Boolean hasWebhookIDKey();
  public interface CeAttributesNested<N> extends Nested<N>,CloudEventAttributesFluent<GitHubSourceStatusFluent.CeAttributesNested<N>>{
    public N and();
    public N endCeAttribute();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<GitHubSourceStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
